translate.storage.ini.Dialect

Package translate :: Package storage :: Module ini :: Class Dialect |
[hide private]
[frames] | no frames]

# Class Dialect

source code

Base class for differentiating dialect options and functions

Instance Methods | [hide private]
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`